@@ -17,7 +17,7 @@ use Feature::Compat::Try;
 use Path::Tiny;
 
 use if $ENV{AUTHOR_TESTING}, 'Test::Warnings' => ':fail_on_warning'; # hooks into done_testing unless overridden
-use Test::JSON::Schema::Acceptance 1.021;
+use Test::JSON::Schema::Acceptance 1.029;
 use Test::Memory::Cycle;
 use Test::File::ShareDir -share => { -dist => { 'JSON-Schema-Modern' => 'share' } };
 use JSON::Schema::Modern;
@@ -108,7 +108,7 @@ sub acceptance_tests (%options) {
               $r->errors;
       }
 
-      $result->valid;
+      ($result->valid, $result->TO_JSON);
     },
     add_resource => $add_resource,
     @ARGV ? (tests => { file => \@ARGV }) : (),
